@@ -38,7 +38,7 @@ try:
 except ImportError:
     pass
 try:
-    import indexed_gzip # type: ignore
+    import indexed_gzip_fileobj_fork_epicfaace as indexed_gzip # type: ignore
 except ImportError:
     pass
 try:
@@ -753,6 +753,7 @@ class SQLiteIndexedTar:
                     # fmt:on
                 )
             except tarfile.ReadError:
+                print("RE")
                 pass
         
         try:
@@ -2073,4 +2074,4 @@ seeking capabilities when opening that file.
         elif ',' in args.index_folders:
             args.index_folders = args.index_folders.split(',')
 
-    return args
\ No newline at end of file
+    return args
