@@ -16,6 +16,7 @@ from apache_beam.io.filesystems import FileSystems
 import tempfile
 import tarfile
 from codalab.lib.beam.ratarmount import SQLiteIndexedTar, FileInfo
+from codalab.lib.beam.streamingzipfile import StreamingZipFile
 from typing import IO, cast
 
 NONE_PLACEHOLDER = '<none>'
@@ -148,7 +149,7 @@ def zip_directory(
             raise IOError(e.output)
 
 
-def unzip_directory(fileobj_or_name, directory_path, force=False):
+def unzip_directory(fileobj: IO[bytes], directory_path: str, force: bool = False):
     """
     Extracts the given file-like object containing a zip archive into the given
     directory, which will be created and should not already exist. If it already exists,
@@ -160,22 +161,14 @@ def unzip_directory(fileobj_or_name, directory_path, force=False):
         remove_path(directory_path)
     os.mkdir(directory_path)
 
-    def do_unzip(filename):
-        # TODO(Ashwin): preserve permissions with -X.
-        exitcode = subprocess.call(['unzip', '-q', filename, '-d', directory_path])
-        if exitcode != 0:
-            raise UsageError('Invalid archive upload. ')
-
-    # If fileobj_or_name is a file object, we have to save it
-    # to a temporary file, because unzip doesn't accept input from standard input.
-    if not isinstance(fileobj_or_name, str):
-        with tempfile.NamedTemporaryFile() as f:
-            shutil.copyfileobj(fileobj_or_name, f)
-            f.seek(0)
-            do_unzip(f.name)
-    else:
-        # In this case, fileobj_or_name is a file name.
-        do_unzip(fileobj_or_name)
+    with StreamingZipFile(fileobj) as zf:
+        for member in zf:  # type: ignore
+            # Make sure that there is no trickery going on (see note in
+            # ZipFile.extractall() documentation).
+            member_path = os.path.realpath(os.path.join(directory_path, member.filename))
+            if not member_path.startswith(directory_path):
+                raise UsageError('Archive member extracts outside the directory.')
+            zf.extract(member, directory_path)
 
 
 class OpenIndexedArchiveFile(object):
@@ -196,10 +189,7 @@ class OpenIndexedArchiveFile(object):
             self.index_file_name = index_fileobj.name
             shutil.copyfileobj(
                 FileSystems.open(
-                    # path can end in either "contents.tar.gz" (if a directory) or "contents.gz" (if a file).
-                    path.replace("/contents.tar.gz", "/index.sqlite").replace(
-                        "/contents.gz", "/index.sqlite"
-                    ),
+                    parse_linked_bundle_url(self.path).index_path,
                     compression_type=CompressionTypes.UNCOMPRESSED,
                 ),
                 index_fileobj,
@@ -208,7 +198,7 @@ class OpenIndexedArchiveFile(object):
     def __enter__(self) -> SQLiteIndexedTar:
         return SQLiteIndexedTar(
             fileObject=self.f,
-            tarFileName=parse_linked_bundle_url(self.path).bundle_uuid,
+            tarFileName="contents",
             writeIndex=False,
             clearIndexCache=False,
             indexFileName=self.index_file_name,
@@ -236,7 +226,8 @@ class OpenFile(object):
             path (str): Path to open; can be a path on disk or a path on Blob Storage.
             mode (str): Mode with which to open the file. Default is "rb". This is only
             gzipped (bool): Whether the output should be gzipped. Must be True if downloading a directory;
-                can be True or False if downloading a file.
+                can be True or False if downloading a file. Note that as of now, gzipping local files from disk
+                from OpenFile is not yet supported (only from Blob Storage).
         """
         self.path = path
         self.mode = mode
@@ -278,7 +269,15 @@ class OpenFile(object):
                     fs = TarFileStream(tf, finfo)
                     return GzipStream(fs) if self.gzipped else fs
         else:
-            # Stream a file from disk storage.
+            # Stream a directory or file from disk storage.
+            if os.path.isdir(self.path):
+                if not self.gzipped:
+                    raise IOError("Directories must be gzipped.")
+                return tar_gzip_directory(self.path)
+            if self.gzipped:
+                raise IOError(
+                    "Gzipping local files from disk from OpenFile is not yet supported. Please use file_util.gzip_file instead."
+                )
             return open(self.path, self.mode)
 
     def __exit__(self, type, value, traceback):
@@ -374,14 +373,15 @@ def get_file_size(file_path):
     """
     linked_bundle_path = parse_linked_bundle_url(file_path)
     if linked_bundle_path.uses_beam and linked_bundle_path.is_archive:
+        # If no archive subpath is specified for a .tar.gz or .gz file, get the compressed size of the entire file.
+        if not linked_bundle_path.archive_subpath:
+            filesystem = FileSystems.get_filesystem(linked_bundle_path.bundle_path)
+            return filesystem.size(linked_bundle_path.bundle_path)
         # If the archive file is a .tar.gz file on Azure, open the specified archive subpath within the archive.
         # If it is a .gz file on Azure, open the "/contents" entry, which represents the actual gzipped file.
         with OpenIndexedArchiveFile(linked_bundle_path.bundle_path) as tf:
-            fpath = (
-                "/" + linked_bundle_path.archive_subpath
-                if linked_bundle_path.is_archive_dir
-                else "/contents"
-            )
+            assert linked_bundle_path.is_archive_dir
+            fpath = "/" + linked_bundle_path.archive_subpath
             finfo = tf.getFileInfo(fpath)
             if finfo is None:
                 raise FileNotFoundError(fpath)
